/* 
 * Settings.java 
 * 
 * Settings screen allows view/edit of server, authentication, and macro values.  Called from Chat Screen 
 * menu option.  Saves values to the persistent store.
 * 
 */

package com.synthdreams;

import net.rim.device.api.system.PersistentObject;
import net.rim.device.api.system.PersistentStore;
import net.rim.device.api.ui.MenuItem;
import net.rim.device.api.ui.component.EditField;
import net.rim.device.api.ui.component.LabelField;
import net.rim.device.api.ui.container.MainScreen;

class Settings extends MainScreen {
   private EditField _serverField;
   private EditField _nameField;
   private EditField _passwordField;
   private EditField _macro1Field;
   private EditField _macro2Field;
   private EditField _macro3Field;
   private EditField _launcherVerField;
   private EditField _protocolVerField;
   
   
   public Settings()
   {
      super(NO_VERTICAL_SCROLL);     
      
      LabelField titleField;
      MenuItem saveItem;
      MenuItem cancelItem;

      _serverField = new EditField("Server: ", "");       
      _nameField = new EditField("Username: ", "");      
      _passwordField = new EditField("Password: ", "");      
      _macro1Field = new EditField("Macro 1: ", "/help");
      _macro2Field = new EditField("Macro 2: ", "/list");
      _macro3Field = new EditField("Macro 3: ", "");
      _launcherVerField = new EditField("Launcher Version (Orig 13): ", "13");
      _protocolVerField = new EditField("Protoocl Version (Orig 29): ", "29");

      
      
      saveItem = new MenuItem("Save Settings", 10, 0) {
         public void run() {
            saveSettings();
            getScreen().close();
         }
      };
      
      cancelItem = new MenuItem("Cancel", 10, 0) {
         public void run() {
            getScreen().close();
         }
      };

      // Set Title
      titleField = new LabelField("BerryCraft Settings");
      setTitle(titleField);
      
      // Set Menu Items
      addMenuItem(saveItem);
      addMenuItem(cancelItem);
      
      // Set Fields
      add(_serverField);
      add(_nameField);
      add(_passwordField);
      add(_macro1Field);
      add(_macro2Field);
      add(_macro3Field);
      add(_launcherVerField);
      add(_protocolVerField);
   }

   public void saveSettings() {
      //com.synthdreams.BerryCraft.Server
      //com.synthdreams.BerryCraft.Name
      //com.synthdreams.BerryCraft.Password
      //com.synthdreams.BerryCraft.Macro1
      //com.synthdreams.BerryCraft.Macro2
      //com.synthdreams.BerryCraft.Macro3
      //com.synthdreams.BerryCraft.Launcher
      //com.synthdreams.BerryCraft.Protocol
      long serverKey = 0xcda03c73b5d096e9L;
      long nameKey = 0x8dc2a03401508f1dL;
      long passwordKey = 0x3c5155de56344bdcL;
      long macro1Key = 0x6c5ab86502573843L;
      long macro2Key = 0x85024dc87b4aba48L;
      long macro3Key = 0xd73d0a43f684ced7L;
      long launcherKey = 0x163461a8f7bbadb0L;
      long protocolKey = 0xed67db8d9656b6d9L;
      PersistentObject persistObject;
      
      persistObject = PersistentStore.getPersistentObject(serverKey);
      persistObject.setContents(_serverField.getText());
      persistObject = PersistentStore.getPersistentObject(nameKey);
      persistObject.setContents(_nameField.getText());
      persistObject = PersistentStore.getPersistentObject(passwordKey);
      persistObject.setContents(_passwordField.getText());
      persistObject = PersistentStore.getPersistentObject(macro1Key);
      persistObject.setContents(_macro1Field.getText());
      persistObject = PersistentStore.getPersistentObject(macro2Key);
      persistObject.setContents(_macro2Field.getText());
      persistObject = PersistentStore.getPersistentObject(macro3Key);
      persistObject.setContents(_macro3Field.getText());
      persistObject = PersistentStore.getPersistentObject(launcherKey);
      persistObject.setContents(_launcherVerField.getText());
      persistObject = PersistentStore.getPersistentObject(protocolKey);
      persistObject.setContents(_protocolVerField.getText());
   }
   
   public void loadSettings() {
      //com.synthdreams.BerryCraft.Server
      //com.synthdreams.BerryCraft.Name
      //com.synthdreams.BerryCraft.Password
      //com.synthdreams.BerryCraft.Macro1
      //com.synthdreams.BerryCraft.Macro2
      //com.synthdreams.BerryCraft.Macro3
      //com.synthdreams.BerryCraft.Launcher
      //com.synthdreams.BerryCraft.Protocol      
      long serverKey = 0xcda03c73b5d096e9L;
      long nameKey = 0x8dc2a03401508f1dL;
      long passwordKey = 0x3c5155de56344bdcL;
      long macro1Key = 0x6c5ab86502573843L;
      long macro2Key = 0x85024dc87b4aba48L;
      long macro3Key = 0xd73d0a43f684ced7L;
      long launcherKey = 0x163461a8f7bbadb0L;
      long protocolKey = 0xed67db8d9656b6d9L;      
      PersistentObject persistObject;
      
      persistObject = PersistentStore.getPersistentObject(serverKey);
      if (persistObject.getContents() != null) {
         _serverField.setText(persistObject.getContents().toString());
      }
      
      persistObject = PersistentStore.getPersistentObject(nameKey);
      if (persistObject.getContents() != null) {
         _nameField.setText(persistObject.getContents().toString());
      }
      
      persistObject = PersistentStore.getPersistentObject(passwordKey);
      if (persistObject.getContents() != null) {
         _passwordField.setText(persistObject.getContents().toString());
      }
      
      persistObject = PersistentStore.getPersistentObject(macro1Key);
      if (persistObject.getContents() != null) {
         _macro1Field.setText(persistObject.getContents().toString());
      }

      persistObject = PersistentStore.getPersistentObject(macro2Key);
      if (persistObject.getContents() != null) {
         _macro2Field.setText(persistObject.getContents().toString());
      }
      
      persistObject = PersistentStore.getPersistentObject(macro3Key);
      if (persistObject.getContents() != null) {
         _macro3Field.setText(persistObject.getContents().toString());
      }

      persistObject = PersistentStore.getPersistentObject(launcherKey);
      if (persistObject.getContents() != null) {
         _launcherVerField.setText(persistObject.getContents().toString());
      }

      persistObject = PersistentStore.getPersistentObject(protocolKey);
      if (persistObject.getContents() != null) {
         _protocolVerField.setText(persistObject.getContents().toString());
      }
   } 
   
   public String getServer() {
      if (_serverField.getText().indexOf(":") > -1) {
         return _serverField.getText();
      }
      else {
         return _serverField.getText() + ":25565";
      }
   }
   
   public String getName() {
      return _nameField.getText();
   }

   public String getPassword() {
      return _passwordField.getText();
   }   
   
   public String getMacro1() {
      return _macro1Field.getText();
   }

   public String getMacro2() {
      return _macro2Field.getText();
   }
   
   public String getMacro3() {
      return _macro3Field.getText();
   }   
   
   public String getLauncherVer() {
      return _launcherVerField.getText();
   }
   
   public String getProtocolVer() {
      return _protocolVerField.getText();
   }
}
